@@ -46,9 +46,6 @@ class FieldTypes(Enum):
     Undefined = auto()
     Date = auto()
 
-    def _generate_next_value_(self, name, start, count, last_values):
-        return name.lower()
-
     @classmethod
     def choices(cls):
         return [(enum.value, enum) for enum in cls]
@@ -178,8 +175,8 @@ class Source(PolymorphicModel, CeleryCallMethodsMixin):
                     field, is_new = self.fields.get_or_create(
                         name=field_name,
                         defaults={"label": field_name},
-                        order=i,
                     )
+                    field.order = i  # force order for update
                     field.sample = []
                     fields[field_name] = field
 
